/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
'use strict';
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const httpRequest = require("request-light");
const vscode = require("vscode");
const jsonContributions_1 = require("./features/jsonContributions");
const npmView_1 = require("./npmView");
const tasks_1 = require("./tasks");
let taskProvider;
function activate(context) {
    return __awaiter(this, void 0, void 0, function* () {
        taskProvider = registerTaskProvider(context);
        registerExplorer(context);
        configureHttpRequest();
        vscode.workspace.onDidChangeConfiguration(() => {
            configureHttpRequest();
        });
        context.subscriptions.push(jsonContributions_1.addJSONProviders(httpRequest.xhr));
    });
}
exports.activate = activate;
function registerTaskProvider(context) {
    if (vscode.workspace.workspaceFolders) {
        let cachedTasks = undefined;
        let flushCache = () => cachedTasks = undefined;
        let watcher = vscode.workspace.createFileSystemWatcher('**/package.json');
        watcher.onDidChange((_e) => flushCache());
        watcher.onDidDelete((_e) => flushCache());
        watcher.onDidCreate((_e) => flushCache());
        context.subscriptions.push(watcher);
        let provider = {
            provideTasks: () => __awaiter(this, void 0, void 0, function* () {
                if (!cachedTasks) {
                    cachedTasks = yield tasks_1.provideNpmScripts();
                }
                return cachedTasks;
            }),
            resolveTask(_task) {
                return undefined;
            }
        };
        return vscode.workspace.registerTaskProvider('npm', provider);
    }
    return undefined;
}
function registerExplorer(context) {
    return __awaiter(this, void 0, void 0, function* () {
        if (vscode.workspace.workspaceFolders) {
            let treeDataProvider = vscode.window.registerTreeDataProvider('npm', new npmView_1.NpmScriptsTreeDataProvider(context));
            context.subscriptions.push(treeDataProvider);
        }
    });
}
function configureHttpRequest() {
    const httpSettings = vscode.workspace.getConfiguration('http');
    httpRequest.configure(httpSettings.get('proxy', ''), httpSettings.get('proxyStrictSSL', true));
}
function deactivate() {
    if (taskProvider) {
        taskProvider.dispose();
    }
}
exports.deactivate = deactivate;

//# sourceMappingURL=https://ticino.blob.core.windows.net/sourcemaps/987c3dccf45ef0447b7b4c52c81794fab2b6dad5/extensions/npm/out/main.js.map
