"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const diagnostics_1 = require("./diagnostics");
class UnusedHighlighter {
    constructor() {
        this._diagnostics = new diagnostics_1.DiagnosticSet();
        this._validate = true;
        this._decorationType = vscode.window.createTextEditorDecorationType({
            opacity: '0.7'
        });
    }
    dispose() {
        this._decorationType.dispose();
    }
    reInitialize() {
        this._diagnostics.clear();
        for (const editor of vscode.window.visibleTextEditors) {
            editor.setDecorations(this._decorationType, []);
        }
    }
    set validate(value) {
        if (this._validate === value) {
            return;
        }
        this._validate = value;
        if (!value) {
            for (const editor of vscode.window.visibleTextEditors) {
                editor.setDecorations(this._decorationType, []);
            }
        }
    }
    diagnosticsReceived(file, diagnostics) {
        // Undocumented flag to enable
        if (!vscode.workspace.getConfiguration('typescript').get('showUnused.experimentalFade')) {
            return;
        }
        this._diagnostics.set(file, diagnostics);
        this._updateCurrentHighlights(file);
    }
    _updateCurrentHighlights(file) {
        for (const editor of vscode.window.visibleTextEditors) {
            if (editor.document.uri.fsPath !== file.fsPath) {
                continue;
            }
            const diagnostics = this._diagnostics.get(editor.document.uri);
            if (diagnostics) {
                editor.setDecorations(this._decorationType, diagnostics.map(x => x.range));
            }
        }
    }
}
exports.UnusedHighlighter = UnusedHighlighter;

//# sourceMappingURL=https://ticino.blob.core.windows.net/sourcemaps/987c3dccf45ef0447b7b4c52c81794fab2b6dad5/extensions/typescript-language-features/out/features/unusedHighlighter.js.map
